@@ -1,11 +1,24 @@
+use std::env;
+use std::ffi::OsStr;
+use std::path::{Path, PathBuf as StdPathBuf};
+
 use async_std::{fs, path::PathBuf, stream::{self, Stream}};
 use futures::StreamExt;
+use itertools::Itertools;
 
 pub struct StubFinder;
 
 impl StubFinder {
+    const LOCAL_DIR: &'static str = "stubr";
     const JSON_EXTENSION: &'static str = "json";
 
+    #[cfg(target_os = "macos")]
+    const LIB_PATH_ENV_VAR: &'static str = "DYLD_FALLBACK_LIBRARY_PATH";
+    #[cfg(target_os = "windows")]
+    const LIB_PATH_ENV_VAR: &'static str = "PATH";
+    #[cfg(target_os = "linux")]
+    const LIB_PATH_ENV_VAR: &'static str = "LD_LIBRARY_PATH";
+
     pub async fn find_all_stubs(from: &PathBuf) -> impl Stream<Item=PathBuf> {
         if from.exists().await {
             if from.is_dir().await {
@@ -26,8 +39,34 @@ impl StubFinder {
         }
         stubs
     }
-}
 
+    pub fn find_app(name: &str) -> StdPathBuf {
+        Self::output_dir()
+            .join(Self::LOCAL_DIR)
+            .join(env::var("CARGO_PKG_NAME").unwrap())
+            .join(name)
+    }
+
+    pub fn output_dir() -> StdPathBuf {
+        env::var(Self::LIB_PATH_ENV_VAR).ok()
+            .and_then(|v| v.split(':').map(StdPathBuf::from).find(|p| Self::is_target_debug(p)))
+            .and_then(|p| p.parent().map(|it| it.to_path_buf()))
+            .expect("Failed locating '/target' directory")
+    }
+
+    fn is_target_debug(path: &Path) -> bool {
+        let is_named = |p: &Path, name: &str| {
+            p.file_name()
+                .and_then(OsStr::to_str)
+                .map(|n| n.split(';').collect_vec())
+                .and_then(|v| v.get(0).map(|it| it.to_string()))
+                == Some(name.to_string())
+        };
+        let debug = is_named(path, "debug");
+        let target = path.parent().map(|p| is_named(&p.to_path_buf(), "target")).unwrap_or_default();
+        debug && target
+    }
+}
 
 #[cfg(test)]
 mod stub_finder_test {
